Installation
============

If you use `Arch Linux` or one of its derivatives, you can install `mcwb` from the `AUR <https://aur.archlinux.org/packages/python-mcwb/>`_.
Otherwise you can install `mcwb` via pip:

.. code-block:: bash

    pip install mcwb


Requirements
============

`mcwb` requires Python 3.8 or higher.
